#!/bin/sh

INSTALL_DIR=${INSTALL_DIR:-/sc/pebble}
PROGNAME=$(basename $0)
RUNDIR=$(dirname $0)
[ -f ${RUNDIR}/common.sh ] && . ${RUNDIR}/common.sh
#[ -f ${INSTALL_DIR}/bin/common.sh ] && . ${INSTALL_DIR}/bin/common.sh

usage() {
		# developer mode: export KAFKA_HEAP_OPTS="-Xmx256M"; export SCHEMA_REGISTRY_HEAP_OPTS=" "; export ZBRIDGE_JVM_OPTIONS=" " ;
        echo "Usage:"
        echo "  $PROGNAME kafka|registry|zookeeper|zbridge|alerts|elasticsearch|esconsumer|all"
		echo "  or"
        echo "  $PROGNAME #to start all installed roles"
        exit 1
}

start_kafka() {
	exit_if_not_installed kafka Starting
	exit_if_already_running kafka "kafka/server.properties"
	#sleep 3 # sometimes kakfa shutting down automatically if ZK is not up. 
	# export KAFKA_JMX_OPTS="-Djava.rmi.server.hostname=ec2-52-26-104-34.us-west-2.compute.amazonaws.com -Djava.net.preferIPv4Stack=true -Dcom.sun.management.jmxremote=true -Dcom.sun.management.jmxremote.authenticate=false -Dcom.sun.management.jmxremote.ssl=false "; export JMX_PORT=${JMX_PORT:-9999}
	cd ${INSTALL_DIR}/conf/kafka/ # for log4j
	# LinkedIn config
	# -Xmx6g -Xms6g -XX:MetaspaceSize=96m -XX:+UseG1GC
	#-XX:MaxGCPauseMillis=20 -XX:InitiatingHeapOccupancyPercent=35 -XX:G1HeapRegionSize=16M
	#-XX:MinMetaspaceFreeRatio=50 -XX:MaxMetaspaceFreeRatio=80
	KAFKA_JMX_OPTS="-Dcom.sun.management.jmxremote=true -Dcom.sun.management.jmxremote.authenticate=false -Dcom.sun.management.jmxremote.ssl=false " \
	JMX_PORT=${JMX_PORT:-9999} \
	KAFKA_HEAP_OPTS=${KAFKA_HEAP_OPTS:-"-Xms8G -Xmx8G"} \
	LOG_DIR=${LOG_DIR:-/sc/pebble/log} \
	KAFKA_LOG4J_OPTS=${KAFKA_LOG4J_OPTS:-"-Dlog4j.configuration=file:${INSTALL_DIR}/conf/kafka/log4j.properties"} \
	nohup ${INSTALL_DIR}/kafka/bin/kafka-server-start ${INSTALL_DIR}/conf/kafka/server.properties 1>>${INSTALL_DIR}/log/kafka.log 2>&1 &
	status_of kafka "kafka/server.properties"
	set_pid_file kafka "kafka/server.properties"
}

start_registry() {
	exit_if_not_installed registry Starting
	exit_if_already_running registry registry
	cd ${INSTALL_DIR}/conf/registry # for log4j
	SCHEMA_REGISTRY_HEAP_OPTS=${SCHEMA_REGISTRY_HEAP_OPTS:-"-Xmx1G"} \
	nohup ${INSTALL_DIR}/registry/bin/schema-registry-start ${INSTALL_DIR}/conf/registry/schema-registry.properties 1>>${INSTALL_DIR}/log/registry.log 2>&1 &
	status_of registry registry
	set_pid_file registry registry
}

start_zookeeper() {
	exit_if_not_installed zookeeper Starting
	exit_if_already_running zookeeper zookeeper
	ZK_JMX_PORT=${ZK_JMX_PORT:-13998}
	ZK_JMX_OPT="-Dcom.sun.management.jmxremote.authenticate=false -Dcom.sun.management.jmxremote.ssl=false -Dcom.sun.management.jmxremote.port=${ZK_JMX_PORT}"
	ZOO_LOG_DIR=${INSTALL_DIR}/log  ZOO_LOG4J_PROP='INFO,ROLLINGFILE' ZOOCFGDIR=${INSTALL_DIR}/conf/zookeeper/ \
		SERVER_JVMFLAGS="${ZK_JMX_OPT}" \
		${INSTALL_DIR}/zookeeper/bin/zkServer.sh start ${INSTALL_DIR}/conf/zookeeper/zoo.cfg
	status_of zookeeper zookeeper
	set_pid_file zookeeper zookeeper
}

start_zbridge() {
	exit_if_not_installed zbridge Starting
	exit_if_already_running zbridge java
	ZBRIDGE_JMX_PORT=${ZBRIDGE_JMX_PORT:-13999}
	#ZBRIDGE_JMX_HOST_OPT="-Djava.rmi.server.hostname="
	ZBRIDGE_JMX_OPTS="-Djava.net.preferIPv4Stack=true -Dcom.sun.management.jmxremote=true -Dcom.sun.management.jmxremote.authenticate=false -Dcom.sun.management.jmxremote.ssl=false -Dcom.sun.management.jmxremote.port=${ZBRIDGE_JMX_PORT}"
	ZBRIDGE_JVM_OPTIONS="-Xmx4G -Xms1G -server -XX:+UseG1GC -XX:MaxGCPauseMillis=20 -XX:InitiatingHeapOccupancyPercent=35 -XX:+DisableExplicitGC"
	ZBRIDGE_JVM_OPTS=${ZBRIDGE_JVM_OPTS:--Xmx4G -Xms1G -server -XX:+UseG1GC -XX:MaxGCPauseMillis=20 -XX:InitiatingHeapOccupancyPercent=35 -XX:+DisableExplicitGC}
	ZBRIDGE_USER_OPTS=${ZBRIDGE_USER_OPTS:-""}
	nohup java ${ZBRIDGE_JMX_OPTS} ${ZBRIDGE_JVM_OPTS} ${ZBRIDGE_USER_OPTS} \
		-cp ${INSTALL_DIR}/lib/ -jar \
		-DconfDir=${INSTALL_DIR}/conf/zbridge/ \
		-Dlog4j.configuration="file:${INSTALL_DIR}/conf/zbridge/log4j.properties" \
		${INSTALL_DIR}/lib/zbridge.jar 1>>${INSTALL_DIR}/log/zbridge.log 2>&1 &
	sleep 2
	status_of zbridge java
	set_pid_file zbridge java
}

start_alerts() {
	exit_if_not_installed alerts Starting
	exit_if_already_running alerts tomcat
	sh ${RUNDIR}/tomcat.sh start
	# pid file 'tomcat.pid' created by tomcat.sh script 
}

start_elasticsearch() {
	exit_if_not_installed elasticsearch Starting
	exit_if_already_running elasticsearch elasticsearch
    perl ${INSTALL_DIR}/bin/EsService.pl elasticsearch start
	set_pid_file elasticsearch elasticsearch
}

start_esconsumer(){
	exit_if_not_installed esconsumer Starting
	exit_if_already_running esconsumer esconsumer
    perl ${INSTALL_DIR}/bin/EsService.pl esconsumer start
	set_pid_file esconsumer esconsumer
}

start_all() {
	# Start all available roles
	[ -f ${INSTALL_DIR}/.role.zookeeper ] && start_zookeeper
	[ -f ${INSTALL_DIR}/.role.kafka ] && start_kafka && sleep 10
	[ -f ${INSTALL_DIR}/.role.registry ] && start_registry
	[ -f ${INSTALL_DIR}/.role.zbridge ] && start_zbridge
	[ -f ${INSTALL_DIR}/.role.alerts ] && start_alerts
	[ -f ${INSTALL_DIR}/.role.elasticsearch ] && start_elasticsearch
	[ -f ${INSTALL_DIR}/.role.esconsumer ] && start_esconsumer
}

if [ $# -eq 0 ] ; then
	start_all
fi

while [ $# -gt 0 ]
do
	case "$1" in
		kafka )
			shift
			start_kafka
			;;
		registry )
			shift
			start_registry
			;;
		zookeeper )
			shift
			start_zookeeper
			;;
		zbridge )
			shift
			start_zbridge
			;;
		alerts )
			shift
			start_alerts
			;;
		elasticsearch )
			shift
			start_elasticsearch
			;;
		esconsumer )
			shift
			start_esconsumer
			;;
		all)
			shift
			start_all
			exit 0
			;;
		*)
			usage
			;;
	esac
done
