#!/bin/sh

INSTALL_DIR=${INSTALL_DIR:-/sc/pebble}
PROGNAME=$(basename $0)
RUNDIR=$(dirname $0)
[ -f ${RUNDIR}/common.sh ] && . ${RUNDIR}/common.sh
#[ -f ${INSTALL_DIR}/bin/common.sh ] && . ${INSTALL_DIR}/bin/common.sh

usage() {
	echo "Usage:"
	echo "  $PROGNAME kafka|registry|zookeeper|zbridge|alerts|elasticsearch|esconsumer|all"
	echo "  or"
    echo "  $PROGNAME #to stop all installed roles"
	exit 1
}

stop_kafka() {
	exit_if_not_installed kafka Stopping
	exit_if_not_running kafka "kafka/server.properties"
	${INSTALL_DIR}/kafka/bin/kafka-server-stop ${INSTALL_DIR}/conf/kafka/server.properties >> ${INSTALL_DIR}/log/kafka.log
	wait_n_kill "kafka/server.properties" 900 "kafka server"
}

stop_registry() {
	exit_if_not_installed registry Stopping
	exit_if_not_running registry schemaregistry
	${INSTALL_DIR}/registry/bin/schema-registry-stop ${INSTALL_DIR}/conf/registry/schema-registry.properties >> ${INSTALL_DIR}/log/registry.log
	wait_n_kill "schemaregistry" 10 "registry"
}

stop_zookeeper() {
	exit_if_not_installed zookeeper Stopping
	exit_if_not_running zookeeper zookeeper
	ZOO_LOG_DIR=${INSTALL_DIR}/log  ZOO_LOG4J_PROP='INFO,ROLLINGFILE' ZOOCFGDIR=${INSTALL_DIR}/conf/zookeeper/ \
	${INSTALL_DIR}/zookeeper/bin/zkServer.sh stop ${INSTALL_DIR}/conf/zookeeper/zoo.cfg
	wait_n_kill zoo.cfg 120 "zookeeper server"
}

stop_zbridge() {
	exit_if_not_installed zbridge Stopping
	exit_if_not_running zbridge java
	pkill -9 -f zbridge.*ar
	/usr/bin/killall -9 java
}

stop_alerts() {
	exit_if_not_installed alerts Stopping
	exit_if_not_running alerts tomcat
	${RUNDIR}/tomcat.sh stop
}

stop_elasticsearch() {
	exit_if_not_installed elasticsearch Stopping
	exit_if_not_running elasticsearch elasticsearch
    perl ${INSTALL_DIR}/bin/EsService.pl elasticsearch stop
}

stop_esconsumer() {
	exit_if_not_installed esconsumer Stopping
	exit_if_not_running esconsumer esconsumer
    perl ${INSTALL_DIR}/bin/EsService.pl esconsumer stop
}

stop_all() {
	# Stop all available roles
	[ -f ${INSTALL_DIR}/.role.kafka ] && stop_kafka
	[ -f ${INSTALL_DIR}/.role.registry ] && stop_registry
	[ -f ${INSTALL_DIR}/.role.zookeeper ] && stop_zookeeper
	[ -f ${INSTALL_DIR}/.role.zbridge ] && stop_zbridge
	[ -f ${INSTALL_DIR}/.role.alerts ] && stop_alerts
	[ -f ${INSTALL_DIR}/.role.elasticsearch ] && stop_elasticsearch
	[ -f ${INSTALL_DIR}/.role.esconsumer ] && stop_esconsumer
}

if [ $# -eq 0 ] ; then
	stop_all
fi

while [ $# -gt 0 ]
do
	case "$1" in
		kafka )
			shift
			stop_kafka
			;;
		registry )
			shift
			stop_registry
			;;
		zookeeper )
			shift
			stop_zookeeper
			;;
		zbridge )
			shift
			stop_zbridge
			;;
		alerts )
			shift
			stop_alerts
			;;
		elasticsearch )
			shift
			stop_elasticsearch
			;;
		esconsumer )
			shift
			stop_esconsumer
			;;
		all)
			shift
			stop_all
			exit 0
			;;
		*)
			usage
			;;
	esac
done
